@@ -6,12 +6,7 @@ very simple html stripper is employed.
 import re
 from typing import Callable, List, Mapping
 
-try:
-    import bleach
-
-    HAS_BLEACH = True
-except ImportError:
-    HAS_BLEACH = False
+import bleach
 
 HtmlTags = List[str]
 HtmlAttributes = Mapping[str, List[str]]
@@ -32,6 +27,4 @@ def bleach_html_stripper(tags: HtmlTags, attributes: HtmlAttributes, val: str) -
 
 
 def default_html_stripper(tags: HtmlTags, attributes: HtmlAttributes, val: str) -> str:
-    if HAS_BLEACH:
-        return bleach_html_stripper(tags, attributes, val)
-    return naive_html_stripper(tags, attributes, val)
+    return bleach_html_stripper(tags, attributes, val)
