@@ -197,11 +197,11 @@ class Validators:
 
     @staticmethod
     def is_not_empty(val: Any) -> bool:
-        """Validates that a string is not empty."""
+        """Validates that a collection is not empty."""
 
-        if not isinstance(val, str):
-            return False
-        return bool(val)
+        if isinstance(val, (str, list, tuple, set, dict)):
+            return len(val) != 0
+        return False
 
     @staticmethod
     def is_match(pattern: str) -> ValidateFieldSync:
